==> go.php?file=PhoenixStyle1.547.zip: PhoenixStyleMod_Firelands/Alysrazor.lua <==
﻿psbossfile53=1
function pscmrboss531(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 1, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss532(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 2, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss533(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables3(name2)
		vezaxsort3()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 3, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss534(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables4(name2)
		vezaxsort4()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 4, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss535(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables5(name2)
		vezaxsort5()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 5, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss536(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables6(name2)
		vezaxsort6()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 6, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss537(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables7(name2)
		vezaxsort7()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 7, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss538(guid2,name2,spellname,spellid)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		if pswasonboss53 and pswasonboss53==1 then
			if psraidoptionson[5][3][9]==1 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][9]], "{rt8} "..name2.." "..psfirelgotm.." |s4id"..spellid.."|id")
			end
		end
		addtotwotables8(name2)
		vezaxsort8()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 18, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss539(guid2,name2,spellname,spellid)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		if pswasonboss53 and pswasonboss53==1 then
			if psraidoptionson[5][3][11]==1 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][11]], "{rt8} "..name2.." "..psfirelgotm.." |s4id"..spellid.."|id")
			end
		end
		addtotwotables9(name2)
		vezaxsort9()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 19, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end


function pscmrbossREPORT531(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss53 and pswasonboss53==1) then

	if pswasonboss53==1 then
		pssetcrossbeforereport1=GetTime()
		if psraidoptionson[5][3][1]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[5][3][2]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[5][3][4]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][4]], true, vezaxname3, vezaxcrash3, 1)
		end
		if psraidoptionson[5][3][5]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99816,100733,100734,100735|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][5]], true, vezaxname4, vezaxcrash4, 1)
		end
		if psraidoptionson[5][3][6]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99336,100725,100726,100727|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][6]], true, vezaxname5, vezaxcrash5, 1)
		end
		if psraidoptionson[5][3][7]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98885,100715,100716,100717|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][7]], true, vezaxname6, vezaxcrash6, 1)
		end
		if psraidoptionson[5][3][8]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99427,100729,100730,100731|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][8]], true, vezaxname7, vezaxcrash7, 1)
		end
		if psraidoptionson[5][3][10]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99558|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][10]], true, vezaxname8, vezaxcrash8, 1)
		end
		if psraidoptionson[5][3][12]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id101666|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][12]], true, vezaxname9, vezaxcrash9, 1)
		end



	end
	if pswasonboss53==1 or (pswasonboss53==2 and try==nil) then

		psiccsavinginf(psbossnames[5][3], try, pswasonboss53)

		strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
		reportafterboitwotab("raid", true, vezaxname4, vezaxcrash4, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
		reportafterboitwotab("raid", true, vezaxname5, vezaxcrash5, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
		reportafterboitwotab("raid", true, vezaxname6, vezaxcrash6, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
		reportafterboitwotab("raid", true, vezaxname7, vezaxcrash7, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99558|id: "
		reportafterboitwotab("raid", true, vezaxname8, vezaxcrash8, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id101666|id: "
		reportafterboitwotab("raid", true, vezaxname9, vezaxcrash9, nil, nil,0,1)

		psiccrefsvin()

	end




	if wipe then
		pswasonboss53=2
		pscheckbossincombatmcr=GetTime()+1
	end
end
end
end


function  pscmrbossRESET531(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss53=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)
table.wipe(vezaxname4)
table.wipe(vezaxcrash4)
table.wipe(vezaxname5)
table.wipe(vezaxcrash5)
table.wipe(vezaxname6)
table.wipe(vezaxcrash6)
table.wipe(vezaxname7)
table.wipe(vezaxcrash7)
table.wipe(vezaxname8)
table.wipe(vezaxcrash8)
table.wipe(vezaxname9)
table.wipe(vezaxcrash9)
pstempalysmobnumb=nil
pstempalysmobnumb2=nil
pstempalysmobnumb3=nil
pstempalysmobnumb4=nil
end
end


function pscombatlogboss53(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)
--local arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15 = ...

if arg2=="SPELL_DAMAGE" and spellid==98463 then
pscmrboss531(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99844 then
pscmrboss532(guid2,name2,spellname)
end

if arg2=="SPELL_AURA_APPLIED" and spellid==100359 then
psunitisplayer(guid2,name2)
if psunitplayertrue then
else
	if psraidoptionson[5][3][3]==1 then
		pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][3]], "{rt8} "..psfiretxtoptt533..": "..name2)
	end
end
end

if arg2=="SPELL_DAMAGE" and spellid==99794 then
pscmrboss533(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99816 or spellid==100733 or spellid==100734 or spellid==100735) then
pscmrboss534(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99336 or spellid==100725 or spellid==100726 or spellid==100727) then
pscmrboss535(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==98885 or spellid==100715 or spellid==100716 or spellid==100717) then
pscmrboss536(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99427 or spellid==100729 or spellid==100730 or spellid==100731) then
pscmrboss537(guid2,name2,spellname)
end



--чтобы не треше не считало фигню
if arg2=="SPELL_CAST_SUCCESS" and (spellid==99605 or spellid==101658 or spellid==101659 or spellid==101660) then
psalysincomb=GetTime()
end


if arg2=="SPELL_CAST_START" and (spellid==101223 or spellid==101294 or spellid==101295 or spellid==101296) and psalysincomb and GetTime()<psalysincomb+750 then

if pstempalysmobnumb==nil then
	pstempalysmobnumb={guid1}
	pstempalysmobnumb2={0}
end

local bil=0
local bil2=0
for i=1,#pstempalysmobnumb do
	if pstempalysmobnumb[i]==guid1 then
		bil=i
		pstempalysmobnumb2[i]=pstempalysmobnumb2[i]+1
		bil2=pstempalysmobnumb2[i]
	end
end
if bil==0 then
	table.insert(pstempalysmobnumb,guid1)
	table.insert(pstempalysmobnumb2,1)
	bil=#pstempalysmobnumb
	bil2=1
end
pscaststartinfo(spellid,spellname..", "..psmob1..": "..bil..". "..pscast1..": "..bil2..".", 4, guid1, 100, spellname.." - "..pseventsincomb2,psbossnames[5][3],1,1)
end


if arg2=="SPELL_CAST_SUCCESS" and spellid==99919 then

if pstempalysmobnumb3==nil then
	pstempalysmobnumb3={guid1}
	pstempalysmobnumb4={0}
end

local bil=0
local bil2=0
for i=1,#pstempalysmobnumb3 do
	if pstempalysmobnumb3[i]==guid1 then
		bil=i
		pstempalysmobnumb4[i]=pstempalysmobnumb4[i]+1
		bil2=pstempalysmobnumb4[i]
	end
end
if bil==0 then
	table.insert(pstempalysmobnumb3,guid1)
	table.insert(pstempalysmobnumb4,1)
	bil=#pstempalysmobnumb3
	bil2=1
end
pscaststartinfo(spellid,spellname..", "..psmob1..": "..bil..". "..pscast1..": "..bil2..".", 4, guid1, 101, spellname.." - "..pseventsincomb2,psbossnames[5][3],1,1)
end


--meteoric impact, heroic
if arg2=="SPELL_DAMAGE" and spellid==99558 then
pscmrboss538(guid2,name2,spellname,spellid)
end

--firestorm
if arg2=="SPELL_DAMAGE" and spellid==101666 then --ыытест ид для 10ки героик не знаю, так же при репорте после боя указать его
pscmrboss539(guid2,name2,spellname,spellid)
end






--НАЙТИ Blazing Power 25 бафов дают:
--НАЙТИ Alysrazor
--6/10 21:32:15.634  SPELL_AURA_REFRESH,0x0100000000318593,"Anntel",0x514,0x10,0x0100000000318593,"Anntel",0x514,0x10,100029,"Alysra's Razor",0x1,DEBUFF
--рефрешится часто, отслеживать не количество а время только, арз в 3 сек обновляют




end

==> go.php?file=PhoenixStyle1.580.zip: PhoenixStyleMod_Firelands/Alysrazor.lua <==
﻿psbossfile53=1
function pscmrboss531(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 1, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss532(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 2, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss533(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables3(name2)
		vezaxsort3()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 3, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss534(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables4(name2)
		vezaxsort4()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 4, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss535(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables5(name2)
		vezaxsort5()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 5, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss536(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables6(name2)
		vezaxsort6()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 6, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss537(guid2,name2,spellname)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables7(name2)
		vezaxsort7()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 7, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss538(guid2,name2,spellname,spellid)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		if pswasonboss53 and pswasonboss53==1 then
			if psraidoptionson[5][3][9]==1 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][9]], "{rt8} "..name2.." "..psfirelgotm.." |s4id"..spellid.."|id")
			end
		end
		addtotwotables8(name2)
		vezaxsort8()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 18, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end

function pscmrboss539(guid2,name2,spellname,spellid)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		if pswasonboss53 and pswasonboss53==1 then
			if psraidoptionson[5][3][11]==1 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][11]], "{rt8} "..name2.." "..psfirelgotm.." |s4id"..spellid.."|id")
			end
		end
		addtotwotables9(name2)
		vezaxsort9()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 19, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end


function pscmrboss5310(guid2,name2,spellname,spellid)

if pswasonboss53==nil then
	pswasonboss53=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss53~=2 then
		psiccwipereport_2("wipe", "try")
	end
		addtotwotables10(name2)
		vezaxsort10()
		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 29, spellname.." - "..psinfo,psbossnames[5][3],2)
end
end


function pscmrbossREPORT531(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss53 and pswasonboss53==1) then

	if pswasonboss53==1 then
		pssetcrossbeforereport1=GetTime()
		if psraidoptionson[5][3][1]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][1]], true, vezaxname, vezaxcrash, 1)
		end
		if psraidoptionson[5][3][2]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][2]], true, vezaxname2, vezaxcrash2, 1)
		end
		if psraidoptionson[5][3][4]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][4]], true, vezaxname3, vezaxcrash3, 1)
		end
		if psraidoptionson[5][3][5]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99816,100733,100734,100735|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][5]], true, vezaxname4, vezaxcrash4, 1)
		end
		if psraidoptionson[5][3][6]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99336,100725,100726,100727|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][6]], true, vezaxname5, vezaxcrash5, 1)
		end
		if psraidoptionson[5][3][7]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id98885,100715,100716,100717|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][7]], true, vezaxname6, vezaxcrash6, 1)
		end
		if psraidoptionson[5][3][8]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99427,100729,100730,100731|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][8]], true, vezaxname7, vezaxcrash7, 1)
		end
		if psraidoptionson[5][3][10]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id99558|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][10]], true, vezaxname8, vezaxcrash8, 1)
		end
		if psraidoptionson[5][3][12]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id101666|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][12]], true, vezaxname9, vezaxcrash9, 1)
		end
		if psraidoptionson[5][3][13]==1 then
			strochkavezcrash=psfireldamagefrom.." |s4id100640|id: "
			reportafterboitwotab(psraidchats3[psraidoptionschat[5][3][13]], true, vezaxname10, vezaxcrash10, 1)
		end



	end
	if pswasonboss53==1 or (pswasonboss53==2 and try==nil) then

		psiccsavinginf(psbossnames[5][3], try, pswasonboss53)

		strochkavezcrash=psfireldamagefrom.." |s4id98463|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99844|id: "
		reportafterboitwotab("raid", true, vezaxname2, vezaxcrash2, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99794|id: "
		reportafterboitwotab("raid", true, vezaxname3, vezaxcrash3, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99816|id: "
		reportafterboitwotab("raid", true, vezaxname4, vezaxcrash4, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99336|id: "
		reportafterboitwotab("raid", true, vezaxname5, vezaxcrash5, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id98885|id: "
		reportafterboitwotab("raid", true, vezaxname6, vezaxcrash6, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99427|id: "
		reportafterboitwotab("raid", true, vezaxname7, vezaxcrash7, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id99558|id: "
		reportafterboitwotab("raid", true, vezaxname8, vezaxcrash8, nil, nil,0,1)

		strochkavezcrash=psfireldamagefrom.." |s4id101666|id: "
		reportafterboitwotab("raid", true, vezaxname9, vezaxcrash9, nil, nil,0,1)
		
		strochkavezcrash=psfireldamagefrom.." |s4id100640|id: "
		reportafterboitwotab("raid", true, vezaxname10, vezaxcrash10, nil, nil,0,1)


		psiccrefsvin()

	end




	if wipe then
		pswasonboss53=2
		pscheckbossincombatmcr_2=GetTime()+1
	end
end
end
end


function  pscmrbossRESET531(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss53=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
table.wipe(vezaxname3)
table.wipe(vezaxcrash3)
table.wipe(vezaxname4)
table.wipe(vezaxcrash4)
table.wipe(vezaxname5)
table.wipe(vezaxcrash5)
table.wipe(vezaxname6)
table.wipe(vezaxcrash6)
table.wipe(vezaxname7)
table.wipe(vezaxcrash7)
table.wipe(vezaxname8)
table.wipe(vezaxcrash8)
table.wipe(vezaxname9)
table.wipe(vezaxcrash9)
table.wipe(vezaxname10)
table.wipe(vezaxcrash10)
pstempalysmobnumb=nil
pstempalysmobnumb2=nil
pstempalysmobnumb3=nil
pstempalysmobnumb4=nil
end
end


function pscombatlogboss53(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)

if arg2=="SPELL_DAMAGE" and spellid==98463 then
pscmrboss531(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and spellid==99844 then
pscmrboss532(guid2,name2,spellname)
end

if arg2=="SPELL_AURA_APPLIED" and spellid==100359 then
psunitisplayer(guid2,name2)
if psunitplayertrue then
else
	if psraidoptionson[5][3][3]==1 then
		pszapuskanonsa(psraidchats3[psraidoptionschat[5][3][3]], "{rt8} "..psfiretxtoptt533..": "..name2)
	end
end
end

if arg2=="SPELL_DAMAGE" and spellid==99794 then
pscmrboss533(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99816 or spellid==100733 or spellid==100734 or spellid==100735) then
pscmrboss534(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99336 or spellid==100725 or spellid==100726 or spellid==100727) then
pscmrboss535(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==98885 or spellid==100715 or spellid==100716 or spellid==100717) then
pscmrboss536(guid2,name2,spellname)
end

if arg2=="SPELL_DAMAGE" and (spellid==99427 or spellid==100729 or spellid==100730 or spellid==100731) then
pscmrboss537(guid2,name2,spellname)
end



--чтобы не треше не считало фигню
if arg2=="SPELL_CAST_SUCCESS" and (spellid==99605 or spellid==101658 or spellid==101659 or spellid==101660) then
psalysincomb=GetTime()
end


if arg2=="SPELL_CAST_START" and (spellid==101223 or spellid==101294 or spellid==101295 or spellid==101296) and psalysincomb and GetTime()<psalysincomb+750 then

if pstempalysmobnumb==nil then
	pstempalysmobnumb={guid1}
	pstempalysmobnumb2={0}
end

local bil=0
local bil2=0
for i=1,#pstempalysmobnumb do
	if pstempalysmobnumb[i]==guid1 then
		bil=i
		pstempalysmobnumb2[i]=pstempalysmobnumb2[i]+1
		bil2=pstempalysmobnumb2[i]
	end
end
if bil==0 then
	table.insert(pstempalysmobnumb,guid1)
	table.insert(pstempalysmobnumb2,1)
	bil=#pstempalysmobnumb
	bil2=1
end
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..", "..psmob1..": "..bil..". "..pscast1..": "..bil2..".", 4, guid1, 100, spellname.." - "..pseventsincomb2,psbossnames[5][3],1,1)
end


if arg2=="SPELL_CAST_SUCCESS" and spellid==99919 then

if pstempalysmobnumb3==nil then
	pstempalysmobnumb3={guid1}
	pstempalysmobnumb4={0}
end

local bil=0
local bil2=0
for i=1,#pstempalysmobnumb3 do
	if pstempalysmobnumb3[i]==guid1 then
		bil=i
		pstempalysmobnumb4[i]=pstempalysmobnumb4[i]+1
		bil2=pstempalysmobnumb4[i]
	end
end
if bil==0 then
	table.insert(pstempalysmobnumb3,guid1)
	table.insert(pstempalysmobnumb4,1)
	bil=#pstempalysmobnumb3
	bil2=1
end
pscheckrunningbossid(guid1)
pscaststartinfo(spellid,spellname..", "..psmob1..": "..bil..". "..pscast1..": "..bil2..".", 4, guid1, 101, spellname.." - "..pseventsincomb2,psbossnames[5][3],1,1)
end


--meteoric impact, heroic
if arg2=="SPELL_DAMAGE" and spellid==99558 then
pscmrboss538(guid2,name2,spellname,spellid)
end

--firestorm
if arg2=="SPELL_DAMAGE" and spellid==101666 then --ыытест ид для 10ки героик не знаю, так же при репорте после боя указать его
pscmrboss539(guid2,name2,spellname,spellid)
end

--Жестокий ветер
if arg2=="SPELL_PERIODIC_DAMAGE" and spellid==100640 then
pscmrboss5310(guid2,name2,spellname,spellid)
end





end
